@@ -1,4 +1,4 @@
-char rcsid_be[] = "$Id: be.c,v 1.1 1997/12/01 22:01:39 waite Exp $";
+char rcsid_be[] = "$Id: be.c,v 1.2 2003/12/21 20:38:17 waite Exp $";
 
 #include <stdio.h>
 #include <string.h>
@@ -20,9 +20,11 @@ static void makeIndex_Map ARGS((Dimension));
 static void makePvector ARGS((void));
 static void makeState ARGS((void));
 static void printPatternAST ARGS((PatternAST));
+static void printPatternAST_int ARGS((PatternAST));
 static void setVectors ARGS((PatternAST));
 static void trailing_zeroes ARGS((int));
 static int seminal ARGS((int from, int to));
+static void printRule ARGS((RuleAST, char *));
 
 static void
 doLabel(op) Operator op;
@@ -145,7 +147,7 @@ makeState()
 
 static char cumBuf[4000];
 static int vecIndex;
-static char vecBuf[4000];
+char vecBuf[4000];
 
 static void
 setVectors(ast) PatternAST ast;
@@ -308,7 +310,7 @@ makeTables()
 	foreachList((ListFn) doMakeTable, operators);
 }
 
-static RuleAST *pVector;
+RuleAST *pVector;
 
 void
 makeLHSmap()
@@ -373,6 +375,34 @@ makeClosureArray()
 	fprintf(outfile, "};\n");
 }
 
+void
+makeCostVector(z,d) int z; DeltaCost d;
+{
+	fprintf(outfile, "\t{");
+#ifdef NOLEX
+	if (z) {
+		fprintf(outfile, "%5d", d);
+	} else {
+		fprintf(outfile, "%5d", 0);
+	}
+#else
+	{
+	int j;
+	for (j = 0; j < DELTAWIDTH; j++) {
+		if (j > 0) {
+			fprintf(outfile, ",");
+		}
+		if (z) {
+			fprintf(outfile, "%5d", d[j]);
+		} else {
+			fprintf(outfile, "%5d", 0);
+		}
+	}
+	}
+#endif /* NOLEX */
+	fprintf(outfile, "}");
+}
+
 void
 makeCostArray()
 {
@@ -384,34 +414,87 @@ makeCostArray()
 
 	fprintf(outfile, "short %s_cost[][%d] = {\n", prefix, DELTAWIDTH);
 	for (i = 0; i <= max_erule_num; i++) {
-		if (i > 0) {
-			fprintf(outfile, ", /* %d */\n", i - 1);
+		makeCostVector(pVector[i], pVector[i] ? pVector[i]->rule->delta : 0);
+		fprintf(outfile, ", /* ");
+		printRule(pVector[i], "(none)");
+		fprintf(outfile, " = %d */\n", i);
+	}
+	fprintf(outfile, "};\n");
+}
+
+void
+makeStateStringArray()
+{
+	int s;
+	int nt;
+	int states;
+	
+	states = globalMap->count;
+	fprintf(outfile, "\nchar * %s_state_string[] = {\n", prefix);
+	fprintf(outfile, "\" not a state\", /* state 0 */\n");
+	for (s = 0; s < states-1; s++) {
+		fprintf(outfile, "\t\"");
+		printRepresentative(outfile, sortedStates[s]);
+		fprintf(outfile, "\", /* state #%d */\n", s+1);
+	}
+	fprintf(outfile, "};\n");
+}
+
+void
+makeDeltaCostArray()
+{
+	int s;
+	int nt;
+	int states;
+	
+	states = globalMap->count;
+	fprintf(outfile, "\nshort %s_delta_cost[%d][%d][%d] = {\n", prefix, states, last_user_nonterminal, DELTAWIDTH);
+	fprintf(outfile, "{{0}}, /* state 0 */\n");
+	for (s = 0; s < states-1; s++) {
+		fprintf(outfile, "{ /* state #%d: ", s+1);
+		printRepresentative(outfile, sortedStates[s]);
+		fprintf(outfile, " */\n", s+1);
+		fprintf(outfile, "\t{0},\n");
+		for (nt = 1; nt < last_user_nonterminal; nt++) {
+			makeCostVector(1, sortedStates[s]->closed[nt].delta);
+			fprintf(outfile, ", /* ");
+			if (sortedStates[s]->closed[nt].rule) {
+				int erulenum = sortedStates[s]->closed[nt].rule->erulenum;
+				printRule(pVector[erulenum], "(none)");
+				fprintf(outfile, " = %d */", erulenum);
+			} else {
+				fprintf(outfile, "(none) */");
+			}
+			fprintf(outfile, "\n");
 		}
-		fprintf(outfile, "\t{");
-#ifdef NOLEX
-		if (pVector[i]) {
-			fprintf(outfile, "%5d", pVector[i]->rule->delta);
-		} else {
-			fprintf(outfile, "%5d", 0);
+		fprintf(outfile, "},\n");
+	}
+	fprintf(outfile, "};\n");
+}
+
+static void
+printPatternAST_int(p) PatternAST p;
+{
+	List l;
+
+	if (p) {
+		switch (p->sym->tag) {
+		case NONTERMINAL:
+			fprintf(outfile, "%5d,", -p->sym->u.nt->num);
+			break;
+		case OPERATOR:
+			fprintf(outfile, "%5d,", p->sym->u.op->num);
+			break;
+		default:
+			assert(0);
 		}
-#else
-		{
-		int j;
-		for (j = 0; j < DELTAWIDTH; j++) {
-			if (j > 0) {
-				fprintf(outfile, ",");
+		if (p->children) {
+			for (l = p->children; l; l = l->next) {
+				PatternAST pat = (PatternAST) l->x;
+				printPatternAST_int(pat);
 			}
-			if (pVector[i]) {
-				fprintf(outfile, "%5d", pVector[i]->rule->delta[j]);
-			} else {
-				fprintf(outfile, "%5d", 0);
-			}
-		}
 		}
-#endif /* NOLEX */
-		fprintf(outfile, "}");
 	}
-	fprintf(outfile, "\n};\n");
 }
 
 static void
@@ -532,6 +615,99 @@ makeNts()
 	fprintf(outfile, "};\n");
 }
 
+static void
+printRule(r,d) RuleAST r; char *d;
+{
+	if (r) {
+		fprintf(outfile, "%s: ", r->rule->lhs->name);
+		printPatternAST(r->pat);
+	} else {
+		fprintf(outfile, "%s", d);
+	}
+}
+
+void
+makeRuleDescArray()
+{
+	int i;
+
+	if (!pVector) {
+		makePvector();
+	}
+
+	if (last_user_nonterminal != max_nonterminal) {
+		/* not normal form */
+		fprintf(outfile, "short %s_rule_descriptor_0[] = { 0, 0 };\n", prefix);
+	} else {
+		fprintf(outfile, "short %s_rule_descriptor_0[] = { 0, 1 };\n", prefix);
+	}
+	for (i = 1; i <= max_erule_num; i++) {
+		if (pVector[i]) {
+			Operator o;
+			NonTerminal t;
+
+			fprintf(outfile, "short %s_rule_descriptor_%d[] = {", prefix, i);
+			fprintf(outfile, "%5d,", -pVector[i]->rule->lhs->num);
+			printPatternAST_int(pVector[i]->pat);
+			fprintf(outfile, " };\n");
+		}
+	}
+
+	fprintf(outfile, "/* %s_rule_descriptors[0][1] = 1 iff grammar is normal form. */\n", prefix);
+	fprintf(outfile, "short * %s_rule_descriptors[] = {\n", prefix);
+	fprintf(outfile, "\t%s_rule_descriptor_0,\n", prefix);
+	for (i = 1; i <= max_erule_num; i++) {
+		if (pVector[i]) {
+			fprintf(outfile, "\t%s_rule_descriptor_%d,\n", prefix, i);
+		} else {
+			fprintf(outfile, "\t%s_rule_descriptor_0,\n", prefix);
+		}
+	}
+	fprintf(outfile, "};\n");
+}
+
+
+void
+makeRuleDescArray2()
+{
+	int i;
+
+	if (!pVector) {
+		makePvector();
+	}
+
+	fprintf(outfile, "struct { int lhs, op, left, right; } %s_rule_struct[] = {\n", prefix);
+	if (last_user_nonterminal != max_nonterminal) {
+		/* not normal form */
+		fprintf(outfile, "\t{-1},");
+	} else {
+		fprintf(outfile, "\t{0},");
+	}
+	fprintf(outfile, " /* 0 if normal form, -1 if not normal form */\n");
+	for (i = 1; i <= max_erule_num; i++) {
+		fprintf(outfile, "\t");
+		if (pVector[i]) {
+			Operator o;
+			NonTerminal t;
+
+			fprintf(outfile, "{");
+			fprintf(outfile, "%5d, %5d, %5d, %5d",
+				pVector[i]->rule->lhs->num,
+				(o = pVector[i]->rule->pat->op) ? o->num : 0,
+				(t = pVector[i]->rule->pat->children[0]) ? t->num : 0,
+				(t = pVector[i]->rule->pat->children[1]) ? t->num : 0
+				);
+			fprintf(outfile, "} /* ");
+			printRule(pVector[i], "0");
+			fprintf(outfile, " = %d */", i);
+		} else {
+			fprintf(outfile, "{0}");
+		}
+		fprintf(outfile, ",\n");
+	}
+	fprintf(outfile, "};\n");
+}
+
 void
 makeStringArray()
 {
@@ -543,16 +719,19 @@ makeStringArray()
 
 	fprintf(outfile, "char *%s_string[] = {\n", prefix);
 	for (i = 0; i <= max_erule_num; i++) {
+		fprintf(outfile, "\t");
 		if (pVector[i]) {
-			fprintf(outfile, "\t\"%s: ", pVector[i]->rule->lhs->name);
-			printPatternAST(pVector[i]->pat);
-			fprintf(outfile, "\",\n");
+			fprintf(outfile, "\"");
+			printRule(pVector[i], "0");
+			fprintf(outfile, "\"");
 		} else {
-			fprintf(outfile, "\t0,\n");
+			fprintf(outfile, "0");
 		}
+		fprintf(outfile, ",\n");
 	}
 	fprintf(outfile, "};\n");
 	fprintf(outfile, "int %s_max_rule = %d;\n", prefix, max_erule_num);
+	fprintf(outfile, "#define %s_Max_rule %d\n", prefix, max_erule_num);
 }
 
 void
@@ -738,6 +917,7 @@ makeOperators()
 	fprintf(outfile, "\n};\n");
 	fprintf(outfile, "int %s_max_op = %d;\n", prefix, maxOperator);
 	fprintf(outfile, "int %s_max_state = %d;\n", prefix, globalMap->count-1);
+	fprintf(outfile, "#define %s_Max_state %d\n", prefix, globalMap->count-1);
 }
 
 void
@@ -835,7 +1015,11 @@ startBurm()
 	fprintf(outfile, "#else\n");
 	fprintf(outfile, "extern void abort();\n");
 	fprintf(outfile, "#endif\n");
+	fprintf(outfile, "#ifdef NDEBUG\n");
+ 	fprintf(outfile, "#define %s_assert(x,y)\t;\n", prefix);
+	fprintf(outfile, "#else\n");
  	fprintf(outfile, "#define %s_assert(x,y)\tif(!(x)) {y; abort();}\n", prefix);
+	fprintf(outfile, "#endif\n");
 }
 
 void
