@@ -1,7 +1,9 @@
-char rcsid_burs[] = "$Id: burs.c,v 1.1 1997/12/01 22:01:39 waite Exp $";
+char rcsid_burs[] = "$Id: burs.c,v 1.2 2003/12/21 20:38:17 waite Exp $";
 
 #include "b.h"
 
+Item_Set errorState;
+
 static void doLeaf ARGS((Operator));
 
 static void
@@ -50,7 +52,7 @@ build()
 	globalMap = newMapping(GLOBAL_MAP_SIZE);
 
 	ts = newItem_Set(0);
-	encode(globalMap, ts, &new);
+	errorState = encode(globalMap, ts, &new);
 	ts->closed = ts->virgin;
 	addQ(globalQ, ts);
 
