@@ -1,4 +1,4 @@
-char rcsid_plank[] = "$Id: plank.c,v 1.1 1997/12/01 22:01:39 waite Exp $";
+char rcsid_plank[] = "$Id: plank.c,v 1.2 2003/12/21 20:38:19 waite Exp $";
 
 #include <stdio.h>
 #include <string.h>
@@ -7,8 +7,9 @@ char rcsid_plank[] = "$Id: plank.c,v 1.1 1997/12/01 22:01:39 waite Exp $";
 
 #define ERROR_VAL 0
 
-int safely = 1;
+int speedflag = 0;
 
+Item_Set *sortedStates;
 static struct stateMapTable smt;
 int exceptionTolerance = 0;
 static int plankSize = 32;
@@ -17,7 +18,7 @@ static Plank newPlank ARGS((void));
 static PlankMap newPlankMap ARGS((int));
 static StateMap newStateMap ARGS((void));
 static Exception newException ARGS((int, int));
-static void enterStateMap ARGS((PlankMap, DeltaPtr, int, int *));
+static void enterStateMap ARGS((PlankMap, short *, int, int *));
 static List assemblePlanks ARGS((void));
 static void assignRules ARGS((RuleAST));
 static int stateCompare ARGS((Item_Set *, Item_Set *));
@@ -91,7 +92,7 @@ newException(index, value) int index; int value;
 }
 
 static void
-enterStateMap(im, v, width, new) PlankMap im; short *v; int width; int *new;
+enterStateMap(im, v, width, new) PlankMap im; short * v; int width; int *new;
 {
 	int i;
 	StateMap sm;
@@ -101,7 +102,7 @@ enterStateMap(im, v, width, new) PlankMap im; short *v; int width; int *new;
 	assert(im);
 	assert(v);
 	assert(width > 0);
-	size = globalMap->count - (safely ? 0 : 1);
+	size = globalMap->count;
 
 	for (l = smt.maps; l; l = l->next) {
 		int ecount;
@@ -172,8 +173,7 @@ assemblePlanks()
 	return planks;
 }
 
-static Item_Set *sortedStates;
-static RuleAST *sortedRules;
+RuleAST *sortedRules;
 
 static int count;
 
@@ -201,7 +201,7 @@ dumpSortedStates()
 	int i;
 	
 	printf("dump Sorted States: ");
-	for (i = 0; i < globalMap->count-(safely?0:1); i++) {
+	for (i = 0; i < globalMap->count; i++) {
 		printf("%d ", sortedStates[i]->num);
 	}
 	printf("\n");
@@ -252,9 +252,7 @@ renumber()
 		if (previousLHS != sortedRules[i]->rule->lhs) {
 			sortedRules[i]->rule->lhs->baseNum = base_counter;
 			previousLHS = sortedRules[i]->rule->lhs;
-			if (safely) {
-				base_counter++; /* make space for 0 */
-			}
+			base_counter++; /* make space for 0 */
 		}
 		sortedRules[i]->rule->newNum = base_counter;
 		sortedRules[i]->rule->lhs->ruleCount++;
@@ -291,27 +289,19 @@ mapToPmap(d) Dimension d;
 	int i;
 	int new;
 
-	if (d->map->count == (2-safely)) {
+	if (d->map->count == 1) {
 		return 0;
 	}
-	assert(d->map->count > (2-safely));
+	assert(d->map->count > 1);
 	im = newPlankMap(0);
 	v = newVector();
-	if (safely) {
-		for (i = 0; i < globalMap->count-1; i++) {
-			int index = d->map->set[d->index_map.class[sortedStates[i]->num]->num]->num;
-			assert(index >= 0);
-			v[i+1] = index;
-		}
-		v[0] = 0;
-		enterStateMap(im, v, width(d->map->count-(safely?0:1)), &new);
-	} else {
-		for (i = 0; i < globalMap->count-1; i++) {
-			int index = d->map->set[d->index_map.class[sortedStates[i]->num]->num]->num;
-			v[i] = index-1;
-		}
-		enterStateMap(im, v, width(d->map->count-(2-safely)), &new);
+	for (i = 0; i < globalMap->count-1; i++) {
+		int index = d->map->set[d->index_map.class[sortedStates[i]->num]->num]->num;
+		assert(index >= 0);
+		v[i+1] = index;
 	}
+	v[0] = 0;
+	enterStateMap(im, v, width(d->map->count), &new);
 	if (!new) {
 		zfree(v);
 	}
@@ -335,22 +325,18 @@ doDimPmaps(op) Operator op;
 		break;
 	case 1:
 		d = op->table->dimen[0];
-		if (d->map->count > 2-safely) {
+		if (d->map->count > 1) {
 			v = newVector();
 			im = newPlankMap(op->baseNum);
 			for (i = 0; i < globalMap->count-1; i++) {
 				int index = d->map->set[d->index_map.class[sortedStates[i]->num]->num]->num;
 				if (index) {
 					Item_Set *ts = transLval(op->table, index, 0);
-					v[i+safely] = (*ts)->newNum - op->baseNum + safely;
-					assert(v[i+safely] >= 0);
-				} else {
-					if (!safely) {
-						v[i] = -1;
-					}
+					v[i+1] = (*ts)->newNum - op->baseNum+1;
+					assert(v[i+1] >= 0);
 				}
 			}
-			enterStateMap(im, v, width(d->map->count-(2-safely)), &new);
+			enterStateMap(im, v, width(d->map->count-1), &new);
 			if (!new) {
 				zfree(v);
 			}
@@ -358,10 +344,10 @@ doDimPmaps(op) Operator op;
 		}
 		break;
 	case 2:
-		if (op->table->dimen[0]->map->count == (2-safely) && op->table->dimen[1]->map->count == (2-safely)) {
+		if (op->table->dimen[0]->map->count == 1 && op->table->dimen[1]->map->count == 1) {
 			op->table->dimen[0]->pmap = 0;
 			op->table->dimen[1]->pmap = 0;
-		} else if (op->table->dimen[0]->map->count == (2-safely)) {
+		} else if (op->table->dimen[0]->map->count == 1) {
 			v = newVector();
 			im = newPlankMap(op->baseNum);
 			d = op->table->dimen[1];
@@ -369,20 +355,16 @@ doDimPmaps(op) Operator op;
 				int index = d->map->set[d->index_map.class[sortedStates[i]->num]->num]->num;
 				if (index) {
 					Item_Set *ts = transLval(op->table, 1, index);
-					v[i+safely] = (*ts)->newNum - op->baseNum+safely;
-					assert(v[i+safely] >= 0);
-				} else {
-					if (!safely) {
-						v[i] = -1;
-					}
+					v[i+1] = (*ts)->newNum - op->baseNum+1;
+					assert(v[i+1] >= 0);
 				}
 			}
-			enterStateMap(im, v, width(d->map->count-(2-safely)), &new);
+			enterStateMap(im, v, width(d->map->count-1), &new);
 			if (!new) {
 				zfree(v);
 			}
 			d->pmap = im;
-		} else if (op->table->dimen[1]->map->count == (2-safely)) {
+		} else if (op->table->dimen[1]->map->count == 1) {
 			v = newVector();
 			im = newPlankMap(op->baseNum);
 			d = op->table->dimen[0];
@@ -390,15 +372,11 @@ doDimPmaps(op) Operator op;
 				int index = d->map->set[d->index_map.class[sortedStates[i]->num]->num]->num;
 				if (index) {
 					Item_Set *ts = transLval(op->table, index, 1);
-					v[i +safely] = (*ts)->newNum - op->baseNum +safely;
-					assert(v[i +safely] >= 0);
-				} else {
-					if (!safely) {
-						v[i] = -1;
-					}
+					v[i +1] = (*ts)->newNum - op->baseNum +1;
+					assert(v[i +1] >= 0);
 				}
 			}
-			enterStateMap(im, v, width(d->map->count-(2-safely)), &new);
+			enterStateMap(im, v, width(d->map->count-1), &new);
 			if (!new) {
 				zfree(v);
 			}
@@ -411,33 +389,33 @@ doDimPmaps(op) Operator op;
 				op->stateCount <= 255 ? "char" : "short",
 				prefix,
 				op->name,
-				op->table->dimen[0]->map->count-(1-safely),
-				op->table->dimen[1]->map->count-(1-safely));
-			for (i = (1-safely); i < op->table->dimen[0]->map->count; i++) {
-				if (i > (1-safely)) {
+				op->table->dimen[0]->map->count,
+				op->table->dimen[1]->map->count);
+			for (i = 0; i < op->table->dimen[0]->map->count; i++) {
+				if (i > 0) {
 					fprintf(outfile, ",");
 				}
 				fprintf(outfile, "\n{");
-				for (j = (1-safely); j < op->table->dimen[1]->map->count; j++) {
+				for (j = 0; j < op->table->dimen[1]->map->count; j++) {
 					Item_Set *ts = transLval(op->table, i, j);
 					short diff;
-					if (j > (1-safely)) {
+					if (j > 0) {
 						fprintf(outfile, ",");
-						if (j % 10 == (1-safely)) {
+						if (j % 10 == 0) {
 							fprintf(outfile, "\t/* row %d, cols %d-%d*/\n",
-								i-(1-safely),
-								j-(11-safely),
-								j-(2-safely));
+								i,
+								j-10,
+								j-1);
 						}
 					}
 					if ((*ts)->num > 0) {
-						diff = (*ts)->newNum - op->baseNum +safely;
+						diff = (*ts)->newNum - op->baseNum +1;
 					} else {
-						diff = safely ? 0 : -1;
+						diff = 0;
 					}
 					fprintf(outfile, "%5d", diff);
 				}
-				fprintf(outfile, "}\t/* row %d */", i-(1-safely));
+				fprintf(outfile, "}\t/* row %d */", i);
 			}
 			fprintf(outfile, "\n};\n");
 		}
@@ -461,7 +439,7 @@ doNonTermPmaps(n) NonTerminal n;
 	if (n->num >= last_user_nonterminal) {
 		return;
 	}
-	if (n->ruleCount <= (safely?0:1)) {
+	if (n->ruleCount <= 0) {
 		return;
 	}
 	im = newPlankMap(n->baseNum);
@@ -470,15 +448,11 @@ doNonTermPmaps(n) NonTerminal n;
 		Rule r = globalMap->set[sortedStates[i]->num]->closed[n->num].rule;
 		if (r) {
 			r->used = 1;
-			v[i+safely] = r->newNum - n->baseNum /*+safely*/;
-			assert(v[i+safely] >= 0);
-		} else {
-			if (!safely) {
-				v[i] = -1;
-			}
+			v[i+1] = r->newNum - n->baseNum /*safely*/;
+			assert(v[i+1] >= 0);
 		}
 	}
-	enterStateMap(im, v, width(n->ruleCount+safely), &new);
+	enterStateMap(im, v, width(n->ruleCount+1), &new);
 	if (!new) {
 		zfree(v);
 	}
@@ -508,7 +482,7 @@ outPlank(p) Plank p;
 
 	fprintf(outfile, "} %s[] = {\n", p->name);
 
-	for (i = 0; i < globalMap->count-(safely?0:1); i++) {
+	for (i = 0; i < globalMap->count; i++) {
 		fprintf(outfile, "\t{");
 		for (f = p->fields; f; f = f->next) {
 			StateMap sm = (StateMap) f->x;
@@ -612,7 +586,7 @@ makePlankRule()
 
 	fprintf(outfile, 
 	"\t%s_assert(state >= 0 && state < %d, %s_PANIC(\"Bad state %%d passed to %s_rule\\n\", state));\n",
-				prefix, globalMap->count-(safely?0:1), prefix, prefix);
+				prefix, globalMap->count, prefix, prefix);
 	fprintf(outfile, "\tswitch(goalnt) {\n");
 
 	for (i = 1; i < last_user_nonterminal; i++) {
@@ -719,14 +693,13 @@ doPlankLabelMacrosSafely(op) Operator op;
 	PlankMap im0;
 	PlankMap im1;
 
-	assert(safely);
 	switch (op->arity) {
 	case -1:
 		fprintf(outfile, "#define %s_%s_state\t0\n", prefix, op->name);
 		break;
 	case 0:
 		fprintf(outfile, "#define %s_%s_state", prefix, op->name);
-		fprintf(outfile, "\t%d\n", op->table->transition[0]->newNum+safely);
+		fprintf(outfile, "\t%d\n", op->table->transition[0]->newNum+1);
 		break;
 	case 1:
 		fprintf(outfile, "#define %s_%s_state(l)", prefix, op->name);
@@ -742,15 +715,21 @@ doPlankLabelMacrosSafely(op) Operator op;
 				}
 				fprintf(outfile, "\t\t}\n");
 			}
-			fprintf(outfile, "\t( (%s_TEMP = %s[l].%s) ? %s_TEMP + %d : 0 )\n",
-				prefix,
-				im0->values->plank->name, im0->values->fieldname,
-				prefix,
-				im0->offset);
+			if (speedflag) {
+				fprintf(outfile, "\t( %s[l].%s + %d )\n",
+					im0->values->plank->name, im0->values->fieldname,
+					im0->offset);
+			} else {
+				fprintf(outfile, "\t( (%s_TEMP = %s[l].%s) ? %s_TEMP + %d : 0 )\n",
+					prefix,
+					im0->values->plank->name, im0->values->fieldname,
+					prefix,
+					im0->offset);
+			}
 		} else {
 			Item_Set *ts = transLval(op->table, 1, 0);
 			if (*ts) {
-				fprintf(outfile, "\t%d\n", (*ts)->newNum+safely);
+				fprintf(outfile, "\t%d\n", (*ts)->newNum+1);
 			} else {
 				fprintf(outfile, "\t%d\n", 0);
 			}
@@ -765,7 +744,7 @@ doPlankLabelMacrosSafely(op) Operator op;
 			Item_Set *ts = transLval(op->table, 1, 1);
 			assert(0);
 			if (*ts) {
-				fprintf(outfile, "\t\treturn %d;\n", (*ts)->newNum+safely);
+				fprintf(outfile, "\t\treturn %d;\n", (*ts)->newNum+1);
 			} else {
 				fprintf(outfile, "\t\treturn %d;\n", 0);
 			}
@@ -815,15 +794,24 @@ doPlankLabelMacrosSafely(op) Operator op;
 			fprintf(outfile, "\t\tbreak;\n");
 			*/
 
-			fprintf(outfile, "\t( (%s_TEMP = %s_%s_transition[%s[l].%s][%s[r].%s]) ? ",
-				prefix,
-				prefix,
-				op->name,
-				im0->values->plank->name, im0->values->fieldname,
-				im1->values->plank->name, im1->values->fieldname);
-			fprintf(outfile, "%s_TEMP + %d : 0 )\n",
-				prefix,
-				op->baseNum);
+			if (speedflag) {
+				fprintf(outfile, "\t( %s_%s_transition[%s[l].%s][%s[r].%s] + %d)\n",
+					prefix,
+					op->name,
+					im0->values->plank->name, im0->values->fieldname,
+					im1->values->plank->name, im1->values->fieldname,
+					op->baseNum);
+			} else {
+				fprintf(outfile, "\t( (%s_TEMP = %s_%s_transition[%s[l].%s][%s[r].%s]) ? ",
+					prefix,
+					prefix,
+					op->name,
+					im0->values->plank->name, im0->values->fieldname,
+					im1->values->plank->name, im1->values->fieldname);
+				fprintf(outfile, "%s_TEMP + %d : 0 )\n",
+					prefix,
+					op->baseNum);
+			}
 		}
 		break;
 	default:
@@ -833,7 +821,6 @@ doPlankLabelMacrosSafely(op) Operator op;
 static void
 doPlankLabelSafely(op) Operator op;
 {
-	assert(safely);
 	fprintf(outfile, "\tcase %d:\n", op->num);
 	switch (op->arity) {
 	case -1:
@@ -888,6 +875,8 @@ makePlankState()
 
 	fprintf(outfile, "\tregister int %s_TEMP;\n", prefix);
 
+	fprintf(outfile, "#ifndef NDEBUG\n");
+
 	fprintf(outfile, "\tswitch (op) {\n");
 	opsOfArity(2);
 	if (max_arity >= 2) {
@@ -906,20 +895,13 @@ makePlankState()
 	opsOfArity(0);
 	fprintf(outfile, "\t\tbreak;\n");
 	fprintf(outfile, "\t}\n");
+	fprintf(outfile, "#endif\n");
 
-	if (safely) {
-		fprintf(outfile, "\tswitch (op) {\n");
-		fprintf(outfile,"\tdefault: %s_PANIC(\"Unknown op %%d in %s_state\\n\", op); abort(); return 0;\n",
-			prefix, prefix);
-		foreachList((ListFn) doPlankLabelSafely, operators);
-		fprintf(outfile, "\t}\n");
-	} else {
-		fprintf(outfile, "\tswitch (op) {\n");
-		fprintf(outfile,"\tdefault: %s_PANIC(\"Unknown op %%d in %s_state\\n\", op); abort(); return 0;\n",
-			prefix, prefix);
-		foreachList((ListFn) doPlankLabel, operators);
-		fprintf(outfile, "\t}\n");
-	}
+	fprintf(outfile, "\tswitch (op) {\n");
+	fprintf(outfile,"\tdefault: %s_PANIC(\"Unknown op %%d in %s_state\\n\", op); abort(); return 0;\n",
+		prefix, prefix);
+	foreachList((ListFn) doPlankLabelSafely, operators);
+	fprintf(outfile, "\t}\n");
 
 	fprintf(outfile, "}\n");
 }
