@@ -1,4 +1,4 @@
-static char RCSid[] = "$Id: dflteot.c,v 1.3 1999/11/28 23:19:03 tony Exp $";
+static char RCSid[] = "$Id: dflteot.c,v 1.4 2003/06/30 00:23:55 tony Exp $";
 /* Copyright 1993, The Regents of the University of Colorado */
 
 /* This file is part of the Eli Module Library.
@@ -33,12 +33,11 @@ char *c; int l, *t; int *s;
 #endif
 /* Process end-of-file
  *   On entry-
- *     c points to the remaining text
- *     l=1
- *     t points to the initial value of the token code
- *       NORETURN if *p != 0
- *       EOFTOKEN if *p == 0
+ *     *c=0
+ *     l=0
+ *     *t=EOFTOKEN
+ *   On exit-
+ *     *t=final classification
  ***/
-{
-  return;
+{ return;
 }
