@@ -1,7 +1,7 @@
 #ifndef ELIPROTO_H
 #define ELIPROTO_H
 
-/* $Id: eliproto.h,v 2.6 1999/11/28 23:19:07 tony Exp $ */
+/* $Id: eliproto.h,v 2.7 2003/06/30 00:23:55 tony Exp $ */
 /* Copyright 1996, The Regents of the University of Colorado */
 
 /* This file is part of the Eli Module Library.
@@ -48,4 +48,14 @@ Suite 330, Boston, MA 02111-1307, USA.  */
 
 #endif
 
+#ifndef CONST
+
+#ifdef PROTO_OK
+#define CONST const
+#else
+#define CONST
+#endif
+
+#endif
+
 #endif
