@@ -22,8 +22,8 @@
 /* Notify changes, as required by the GPL:
 
 $Log: obstack.c,v $
-Revision 1.20  1999/11/28 23:19:31  tony
-Regenerated for 4.3 release
+Revision 1.21  2003/06/30 00:23:52  tony
+Fixes to previous fix for error backtracking
 
 Revision 2.2  1997/10/21 16:56:24  kadhim
 add __cplusplus to #ifdef's to allow for proper C++ compilation
