@@ -104,12 +104,8 @@ Summary:
 /* Notify changes, as required by the GPL:
 
 $Log: obstack.h,v $
-Revision 1.19  1999/11/28 23:19:33  tony
-Regenerated for 4.3 release
-
-Revision 2.3  1998/03/20 12:08:44  mjung
-In obstack_known_chunk, the wrong alignment-mask was set for
-Non-ANSI-C-Compilers.
+Revision 1.20  2003/06/30 00:23:52  tony
+Fixes to previous fix for error backtracking
 
 Revision 2.3  1998/03/20 12:04:23  mjung
 In obstack_known_chunk, the wrong alignment-mask was set for
