@@ -7,5 +7,5 @@ extern int p234567890();
 int n;
 int n234567890;
 
-int q() { x = p(); }
-int q234567890() { x234567890 = p234567890(); }
+void q() { x = p(); }
+void q234567890() { x234567890 = p234567890(); }
