@@ -1,4 +1,4 @@
-static char rcsid[] = "$Id: rdsymb.c,v 1.3 2002/09/29 22:33:28 waite Exp $";
+static char rcsid[] = "$Id: rdsymb.c,v 1.5 2004/05/07 21:50:27 profw Exp $";
 /* Object file symbol extractor
    Copyright 2002, The Regents of the University of Colorado */
 
@@ -63,6 +63,168 @@ extern char *malloc();
 
 #include "symbinfo.h"
 
+/* ELF helper functions */
+#if ELF_BINARIES
+
+static int
+check_elf_type(int fd, char *file_name)
+/* Determine type of ELF file
+ *   On entry-
+ *     fd=File descriptor to read from
+ *     file_name=file from which to obtain the symbols
+ *   On exit-
+ *     return value=ELFCLASS* (ELFCLASSNONE on error)
+ ***/
+{
+  size_t result;
+  Elf32_Ehdr ehdr;
+
+  if ((result = read(fd, &ehdr, sizeof(ehdr))) != sizeof(ehdr)) {
+    if (result == -1) perror(file_name);
+    else if (result == 0) (void)fprintf(stderr, "%s empty\n", file_name);
+    else (void)fprintf(stderr, "%s is not an ELF file\n", file_name);
+    return ELFCLASSNONE;
+  }
+  lseek(fd, SEEK_SET, 0);
+
+  if (ehdr.e_ident[EI_MAG0] != ELFMAG0 || ehdr.e_ident[EI_MAG1] != ELFMAG1
+   || ehdr.e_ident[EI_MAG2] != ELFMAG2 || ehdr.e_ident[EI_MAG3] != ELFMAG3) {
+    (void)fprintf(stderr, "%s is not an ELF file\n", file_name);
+    return ELFCLASSNONE;
+  }
+
+  if (EI_VERSION < 1) {
+    (void)fprintf(stderr, "Not configured to handle %s\n", file_name);
+    return ELFCLASSNONE;
+  }
+
+  return ehdr.e_ident[EI_CLASS];
+}
+
+#define DEFINE_ELF_READER(SIZE) \
+static void \
+read_elf_##SIZE##_symbols(int fd, char *file_name) \
+/* Read symbols of ELF#SIZE# file \
+ *   On entry- \
+ *     fd=File descriptor to read from \
+ *     file_name=file from which to obtain the symbols \
+ *   On exit- \
+ *       SymbolInfo(symbol,external) has been invoked for each symbol \
+ ***/ \
+{ size_t result; \
+  Elf##SIZE##_Ehdr ehdr; \
+  Elf##SIZE##_Shdr *shdr; \
+  Elf##SIZE##_Half shndx; \
+  Elf##SIZE##_Sym *symbols = (Elf##SIZE##_Sym *)0; \
+  Elf##SIZE##_Sym *limit = (Elf##SIZE##_Sym *)0; \
+  Elf##SIZE##_Sym *p; \
+  char *section_names, *symbol_strings = (char *)0; \
+\
+  if ((result = read(fd, &ehdr, sizeof(ehdr))) != sizeof(ehdr)) { \
+    if (result == -1) perror(file_name); \
+    else if (result == 0) (void)fprintf(stderr, "%s empty\n", file_name); \
+    else (void)fprintf(stderr, "%s is not an ELF file\n", file_name); \
+    return; \
+  } \
+\
+  if (ehdr.e_type != ET_REL) { \
+    (void)fprintf(stderr, "%s is not an object file\n", file_name); \
+    exit(1); \
+  } \
+\
+  if (ehdr.e_shstrndx == SHN_UNDEF) { \
+    (void)fprintf(stderr, "%s has no section names\n", file_name); \
+    exit(1); \
+  } \
+\
+  if (ehdr.e_shoff == 0) return; \
+  if (lseek(fd, (off_t)ehdr.e_shoff, SEEK_SET) == -1) { \
+    perror(file_name); \
+    exit(1); \
+  } \
+\
+  result = ehdr.e_shentsize * ehdr.e_shnum; \
+  if (!(shdr = (Elf##SIZE##_Shdr *)malloc(result))) { \
+    (void)fprintf(stderr, "No space for section headers\n"); \
+    exit(1); \
+  } \
+  if (read(fd, shdr, result) != result) { \
+    (void)fprintf(stderr, "%s: Error reading section headers\n", file_name); \
+    exit(1); \
+  } \
+\
+  if (!(section_names = (char *)malloc((unsigned)shdr[ehdr.e_shstrndx].sh_size))) { \
+    (void)fprintf(stderr, "No space for section names\n"); \
+    exit(1); \
+  } \
+  if (lseek(fd, (off_t)shdr[ehdr.e_shstrndx].sh_offset, SEEK_SET) == -1) { \
+    (void)fprintf (stderr, "Cannot find section names: %s\n", file_name); \
+    exit(1); \
+  } \
+  if (read(fd, section_names, (size_t)shdr[ehdr.e_shstrndx].sh_size) != shdr[ehdr.e_shstrndx].sh_size) { \
+    (void)fprintf (stderr, "Cannot read section names: %s\n", file_name); \
+    exit(1); \
+  } \
+\
+  for (shndx = 0; shndx < ehdr.e_shnum; shndx++) { \
+    if (shdr[shndx].sh_type == SHT_SYMTAB && \
+        strcmp(section_names + shdr[shndx].sh_name,".symtab") == 0) { \
+      if (!(symbols = (Elf##SIZE##_Sym *)malloc((unsigned)shdr[shndx].sh_size))) { \
+        (void)fprintf(stderr, "No space for symbol table\n"); \
+        exit(1); \
+      } \
+      limit = symbols + (shdr[shndx].sh_size / shdr[shndx].sh_entsize); \
+      if (lseek(fd, (off_t)shdr[shndx].sh_offset, SEEK_SET) == -1) { \
+        (void)fprintf (stderr, "Cannot find symbol table: %s\n", file_name); \
+        exit(1); \
+      } \
+      if (read(fd, symbols, (size_t)shdr[shndx].sh_size) != shdr[shndx].sh_size) { \
+        (void)fprintf (stderr, "Cannot read symbol table: %s\n", file_name); \
+        exit(1); \
+      } \
+    } else if (shdr[shndx].sh_type == SHT_STRTAB && \
+               strcmp(section_names + shdr[shndx].sh_name,".strtab") == 0) { \
+      if (shndx == ehdr.e_shstrndx) symbol_strings = section_names; \
+      else { \
+        if (!(symbol_strings = (char *)malloc((unsigned)shdr[shndx].sh_size))) { \
+          (void)fprintf(stderr, "No space for symbol strings\n"); \
+          exit(1); \
+        } \
+        if (lseek(fd, (off_t)shdr[shndx].sh_offset, SEEK_SET) == -1) { \
+          (void)fprintf (stderr, "Cannot find symbol strings: %s\n", file_name); \
+          exit(1); \
+        } \
+        if (read(fd, symbol_strings, (size_t)shdr[shndx].sh_size) != shdr[shndx].sh_size) { \
+          (void)fprintf (stderr, "Cannot read symbol strings: %s\n", file_name); \
+          exit(1); \
+        } \
+      } \
+    } \
+  } \
+\
+  for (p = symbols; p < limit; p++) { \
+    if (ELF##SIZE##_ST_BIND(p->st_info) == STB_GLOBAL) { \
+      if (p->st_shndx == SHN_UNDEF) \
+        SymbolInfo(symbol_strings+p->st_name, 1); \
+      else \
+        SymbolInfo(symbol_strings+p->st_name, 0); \
+    } \
+  } \
+\
+  free(symbol_strings); \
+  free(symbols); \
+  free(shdr); \
+}
+
+
+DEFINE_ELF_READER(32);
+DEFINE_ELF_READER(64);
+
+
+#endif /* ELF_BINARIES */
+/* End of ELF helper functions */
+
+
 /***/
 void
 #if defined(__cplusplus) || defined(__STDC__)
@@ -79,124 +241,30 @@ char *file_name;
  ***/
 {
 #if ELF_BINARIES
+
   int fd;
-  size_t result;
-  Elf32_Ehdr ehdr;
-  Elf32_Shdr *shdr;
-  Elf32_Half shndx;
-  Elf32_Sym *symbols, *limit, *p;
-  char *section_names, *symbol_strings;
-    
+
   if ((fd = open (file_name, O_RDONLY, 0)) == -1) {
     (void)fprintf(stderr, "Cannot open executable: %s\n", file_name);
     exit(1);
   }
 
-  if ((result = read(fd, &ehdr, sizeof(ehdr))) != sizeof(ehdr)) {
-    if (result == -1) perror(file_name);
-    else if (result == 0) (void)fprintf(stderr, "%s empty\n", file_name);
-    else (void)fprintf(stderr, "%s is not an ELF file\n", file_name);
-    exit(1);
+  switch (check_elf_type(fd, file_name)) {
+
+  case ELFCLASS32:
+    read_elf_32_symbols(fd, file_name);
+    break;
+
+  case ELFCLASS64:
+    read_elf_64_symbols(fd, file_name);
+    break;
+
+  case ELFCLASSNONE:
+  default:
+    exit(1); /* Fatal error, already signalled */
+
   }
 
-  if (ehdr.e_ident[EI_MAG0] != ELFMAG0 || ehdr.e_ident[EI_MAG1] != ELFMAG1
-   || ehdr.e_ident[EI_MAG2] != ELFMAG2 || ehdr.e_ident[EI_MAG3] != ELFMAG3) {
-    (void)fprintf(stderr, "%s is not an ELF file\n", file_name);
-    exit(1);
-  }
-
-  if (ehdr.e_ident[EI_CLASS] != ELFCLASS32 || EI_VERSION < 1) {
-    (void)fprintf(stderr, "Not configured to handle %s\n", file_name);
-    exit(1);
-  }
-
-  if (ehdr.e_type != ET_REL) {
-    (void)fprintf(stderr, "%s is not an object file\n", file_name);
-    exit(1);
-  }
-
-  if (ehdr.e_shstrndx == SHN_UNDEF) {
-    (void)fprintf(stderr, "%s has no section names\n", file_name);
-    exit(1);
-  }
-
-  if (ehdr.e_shoff == 0) return;
-  if (lseek(fd, (off_t)ehdr.e_shoff, SEEK_SET) == -1) {
-    perror(file_name);
-    exit(1);
-  }
-
-  result = ehdr.e_shentsize * ehdr.e_shnum;
-  if (!(shdr = (Elf32_Shdr *)malloc(result))) {
-    (void)fprintf(stderr, "No space for section headers\n");
-    exit(1);
-  }
-  if (read(fd, shdr, result) != result) {
-    (void)fprintf(stderr, "%s: Error reading section headers\n", file_name);
-    exit(1);
-  }
-
-  if (!(section_names = (char *)malloc((unsigned)shdr[ehdr.e_shstrndx].sh_size))) {
-    (void)fprintf(stderr, "No space for section names\n");
-    exit(1);
-  }
-  if (lseek(fd, (off_t)shdr[ehdr.e_shstrndx].sh_offset, SEEK_SET) == -1) {
-    (void)fprintf (stderr, "Cannot find section names: %s\n", file_name);
-    exit(1);
-  }
-  if (read(fd, section_names, (size_t)shdr[ehdr.e_shstrndx].sh_size) != shdr[ehdr.e_shstrndx].sh_size) {
-    (void)fprintf (stderr, "Cannot read section names: %s\n", file_name);
-    exit(1);
-  }
-
-  for (shndx = 0; shndx < ehdr.e_shnum; shndx++) {
-    if (shdr[shndx].sh_type == SHT_SYMTAB &&
-        strcmp(section_names + shdr[shndx].sh_name,".symtab") == 0) {
-      if (!(symbols = (Elf32_Sym *)malloc((unsigned)shdr[shndx].sh_size))) {
-        (void)fprintf(stderr, "No space for symbol table\n");
-        exit(1);
-      }
-      limit = symbols + (shdr[shndx].sh_size / shdr[shndx].sh_entsize);
-      if (lseek(fd, (off_t)shdr[shndx].sh_offset, SEEK_SET) == -1) {
-        (void)fprintf (stderr, "Cannot find symbol table: %s\n", file_name);
-        exit(1);
-      }
-      if (read(fd, symbols, (size_t)shdr[shndx].sh_size) != shdr[shndx].sh_size) {
-        (void)fprintf (stderr, "Cannot read symbol table: %s\n", file_name);
-        exit(1);
-      }
-    } else if (shdr[shndx].sh_type == SHT_STRTAB &&
-               strcmp(section_names + shdr[shndx].sh_name,".strtab") == 0) {
-      if (shndx == ehdr.e_shstrndx) symbol_strings = section_names;
-      else {
-        if (!(symbol_strings = (char *)malloc((unsigned)shdr[shndx].sh_size))) {
-          (void)fprintf(stderr, "No space for symbol strings\n");
-          exit(1);
-        }
-        if (lseek(fd, (off_t)shdr[shndx].sh_offset, SEEK_SET) == -1) {
-          (void)fprintf (stderr, "Cannot find symbol strings: %s\n", file_name);
-          exit(1);
-        }
-        if (read(fd, symbol_strings, (size_t)shdr[shndx].sh_size) != shdr[shndx].sh_size) {
-          (void)fprintf (stderr, "Cannot read symbol strings: %s\n", file_name);
-          exit(1);
-        }
-      }
-    }
-  }
-
-  for (p = symbols; p < limit; p++) {
-    if (ELF32_ST_BIND(p->st_info) == STB_GLOBAL) {
-      if (p->st_shndx == SHN_UNDEF)
-        SymbolInfo(symbol_strings+p->st_name, 1);
-      else
-        SymbolInfo(symbol_strings+p->st_name, 0);
-    }
-  }
-
-  free(symbol_strings);
-  free(symbols);
-  free(shdr);
   (void)close(fd);
 #else /* Not ELF_BINARIES */
 
