@@ -1,4 +1,4 @@
-static char RCSid[] = "$Id: mapper.c,v 1.6 1999/10/20 04:56:30 tony Exp $";
+static char RCSid[] = "$Id: mapper.c,v 1.7 2004/08/01 01:44:25 profw Exp $";
 /*##############################################################################
 
 FUNNNELWEB COPYRIGHT
@@ -37,6 +37,8 @@ Changes:
    26-Jul-1992  AMS  Added RCS id.
    18-Dec-1992  WMW  Cast the results of mm_perm to avoid pointer
                      incompatibility.
+   27-Mar-2003	WMW  Changed stan_map to standardize newlines regardless
+		     of the file format
 
 ##############################################################################*/
 
@@ -325,8 +327,16 @@ ulong  *p_length;
     /* fgets doesn't return a length so we have to hobble behind with strlen. */
     /* It's still probably better than using lots of fgetc calls.             */
     /* If we hit EOF and no bytes were read, the EOS we planted saves us.     */
-    bytes_read  = strlen(p_curr);
-    p_curr     += bytes_read;
+    /* bytes_read  = strlen(p_curr);                                          */
+    /* p_curr     += bytes_read;                                              */
+    /* WMW -- Replace the lines above with the following standardization code */
+    for (bytes_read = 0; *p_curr != EOS; bytes_read++) {
+      if (p_curr[0] == '\r') {
+        p_curr[0] = EOL;
+        if (p_curr[1] == EOL) p_curr[1] = EOS;
+      }
+      p_curr++;
+    }
     bytes_left -= bytes_read;
 
     /* If we have run out of bytes in our allocated memory zone, then the     */
