@@ -1,4 +1,4 @@
-static char RCSid[] = "$Id: weavehtml.c,v 2.15 2002/12/27 20:36:59 waite Exp $";
+static char RCSid[] = "$Id: weavehtml.c,v 2.16 2004/08/01 23:15:02 profw Exp $";
 /*##############################################################################
 
 FUNNNELWEB COPYRIGHT
@@ -40,6 +40,7 @@ Changes:
    18-Aug-1996	WMW  Output <P> if needed before @{ and @/
    06-Aug-1997	WMW  Add non-product files
    25-Dec-2002  FRL  Made HTML-Output valid HTML 3.2
+   02-Aug-2004	WMW  Remove </P> and handle blank lines in echoed tags
 
 ##############################################################################*/
 
@@ -265,14 +266,12 @@ p_scls_t p_scls;
     { char *p;
       for (p = p_sc->sc_first; p <= p_sc->sc_last; p++) {
         char c = *p;
-        if (c == '<' || c == '>') ParState = 0;
+        if (c == '<') ParState = 4;
         switch (ParState) {
         case 0:	/* Beginning of text area */
-          if (c != ' ' && c != '\t' && c != '\n' && c != '<' && c != '>')
-	    {
-	      wf_wl(&f_t, "<p>");
-	      ParState = 1;
-	    }
+          if (c != ' ' && c != '\t' && c != '\n') {
+	    ParState = 1;
+	  }
           wf_chr(&f_t, c);
           break;
         case 1:	/* In text */
@@ -287,8 +286,13 @@ p_scls_t p_scls;
           break;
         case 3:	/* At least one blank line */
           if (c != ' ' && c != '\t' && c != '\n') {
-            ParState = 1; wf_wl(&f_t, "</p>\n<p>"); wf_chr(&f_t, c);
+            ParState = 1; wf_wl(&f_t, "<p>"); wf_chr(&f_t, c);
           }
+          break;
+        case 4: /* Inside an HTML tag */
+          if (c == '>') ParState = 0;
+          wf_chr(&f_t, c);
+          break;
         }
       }
     }
