@@ -1,4 +1,4 @@
-static char RCSid[] = "$Id: weaveinfo.c,v 1.20 1999/10/20 04:57:08 tony Exp $";
+static char RCSid[] = "$Id: weaveinfo.c,v 1.21 2004/06/18 14:34:09 profw Exp $";
 /*##############################################################################
 
 FUNNNELWEB COPYRIGHT
@@ -51,6 +51,7 @@ Changes:
    27-Jan-1997  MTJ  Include @setchapternewpage odd in the heading of the
 		     generated info-file
    06-Aug-1997	WMW  Add non-product files
+   18-Jun-2004	WMW  Delete obsolete @aboveenvskipamount command
 
 ##############################################################################*/
 
@@ -984,9 +985,6 @@ p_fn_t fn_targ;
  /* tex_head(&f_t); */
  wf_wl(&f_t,"\\input texinfo");
  wf_wl(&f_t,"@setchapternewpage odd");
- wf_wl(&f_t,"@iftex");
- wf_wl(&f_t,"@aboveenvskipamount=-10pt");
- wf_wl(&f_t,"@end iftex");
 
  fn_split (fn_targ, fn_targ_path, fn_targ_name, fn_targ_extn);
  wf_wr (&f_t, "@setfilename ");
