@@ -1,5 +1,5 @@
 #!/bin/sh
-# $Id: help.sh,v 2.4 2002/05/08 15:00:56 waite Exp $
+# $Id: help.sh,v 2.6 2004/06/29 15:05:45 profw Exp $
 # Copyright 1997, The Regents of the University of Colorado
 
 # This file is part of the Eli translator construction system.
@@ -18,10 +18,12 @@
 # with Eli; see the file COPYING.  If not, write to the Free Software
 # Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
-# EXEC (help.sh) (.) (:filtered) (:errfiles :list :pasted)
+# EXEC (help.sh) (help_header) (help_trailer) (hypermsg.exe) (:filtered)
+#      (:errfiles :list :pasted)
 #   => (:help_tnf);
 
-PKG=$1;shift; ODIN_sorted_errors=$1;shift; ODIN_files=$1;shift;
+ODIN_header=$1;shift; ODIN_trailer=$1;shift; ODIN_hypermsg=$1;shift;
+ODIN_sorted_errors=$1;shift; ODIN_files=$1;shift;
 touch help_tnf
 
 if test ! -s "$ODIN_sorted_errors"; then exit 0; fi
@@ -31,6 +33,6 @@ SED=$ODINCACHE/PKGS/skeleton/sed.exe
 $SED -e 's,\([^	]*\)	\(.*\),/Messages for /s;\1;\2;,' $ODIN_files \
 	> SCRIPT
 
-cat $ODINCACHE/PKGS/info/help_header > help_tnf
-$PKG/hypermsg.exe $ODIN_sorted_errors | $SED -f SCRIPT >> help_tnf
-cat $ODINCACHE/PKGS/info/help_trailer >> help_tnf
+cat $ODIN_header > help_tnf
+$ODIN_hypermsg $ODIN_sorted_errors | $SED -f SCRIPT >> help_tnf
+cat $ODIN_trailer >> help_tnf
