@@ -1,5 +1,5 @@
 #!/bin/sh
-# $Id: info_data.sh,v 2.4 2002/05/08 15:00:56 waite Exp $
+# $Id: info_data.sh,v 2.5 2004/06/21 14:01:00 profw Exp $
 # Copyright 1990, The Regents of the University of Colorado
 
 # This file is part of the Eli translator construction system.
@@ -18,22 +18,18 @@
 # with Eli; see the file COPYING.  If not, write to the Free Software
 # Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
-ODIN_RUNDIR=`pwd`;
-PKG=$1;shift; ODIN_tnf=$1;shift;  mkdir info_data;
+# EXEC (info_data.sh) (texinfo/makeinfo.exe) (:tnf)
+#   => (:info_data);
 
-#info_data[.none] "Data for the hypertext browser"* :
-#	USER
-#		: tnf
+ODIN_makeinfo=$1;shift; ODIN_tnf=$1;shift;
+mkdir info_data;
 
-cd ./info_data
+cd info_data
 
-$ODINCACHE/PKGS/info/texinfo/makeinfo.exe \
-  $ODIN_tnf -o `basename $ODIN_tnf .tnf` >/dev/null 2>$ODIN_RUNDIR/Report
+$ODIN_makeinfo $ODIN_tnf -o `basename $ODIN_tnf .tnf` >/dev/null 2>../Report
 
-if test -s $ODIN_RUNDIR/Report
+if test -s ../Report
 then
-	grep 'Warning' $ODIN_RUNDIR/Report >WARNINGS
-	grep -v 'Warning' $ODIN_RUNDIR/Report >ERRORS
+	grep 'Warning' ../Report >WARNINGS
+	grep -v 'Warning' ../Report >ERRORS
 fi
-
-exit 0
