@@ -1,5 +1,5 @@
 #!/bin/sh
-# $Id: makeinfo.sh,v 2.3 2002/05/08 15:00:56 waite Exp $
+# $Id: makeinfo.sh,v 2.5 2004/06/22 12:35:22 profw Exp $
 # Copyright 1994, The Regents of the University of Colorado
 
 # This file is part of the Eli translator construction system.
@@ -18,11 +18,14 @@
 # with Eli; see the file COPYING.  If not, write to the Free Software
 # Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
-ODIN_RUNDIR=`pwd`
-ODIN_tnf=$1;shift; ODIN_dir=$1;shift; ODIN_node=$1;shift;
+# EXEC (makeinfo.sh) (texinfo/makeinfo.exe) (:tnf) tnf_dir tnf_node
+#   => (:tnf_dir) (:tnf_node);
+
+ODIN_makeinfo=$1;shift; ODIN_tnf=$1;shift;
+ODIN_dir=$1;shift; ODIN_node=$1;shift;
 mkdir $ODIN_dir; touch $ODIN_node
 
-if test ! -s "$ODIN_tnf"; then exit 0; fi
+if test ! -s $ODIN_tnf; then exit 0; fi
 
 SED=$ODINCACHE/PKGS/skeleton/sed.exe
 
@@ -31,10 +34,9 @@ $SED -n -e '/@setfilename/s/@setfilename \(.*\)$/(\1)/p' $ODIN_tnf \
 
 cd $ODIN_dir
 
-$SED -e '/^@egfiles/s;\.;'"$ODIN_dir"';' $ODIN_tnf \
-	> TEXINFO
+$SED -e '/^@egfiles/s;\.;'"$ODIN_dir"';' $ODIN_tnf > TEXINFO
 
-$ODINCACHE/PKGS/info/texinfo/makeinfo.exe TEXINFO 1>/dev/null 2>ERROR
+$ODIN_makeinfo TEXINFO 1>/dev/null 2>ERROR
 
 if test -s ERROR
 then
@@ -42,7 +44,7 @@ then
 (|'"$ODIN_tnf"'|line_err|
 			s;^[^:]*:\([0-9]*\):;'"$ODIN_tnf"' \1 0;
 			$a\
-|)' ERROR > $ODIN_RUNDIR/ERRORS
+|)' ERROR > ../ERRORS
 else
 	rm TEXINFO ERROR
 fi
