@@ -1,5 +1,5 @@
 #!/bin/sh
-# $Id: std_err.sh,v 2.4 2002/05/08 15:00:56 waite Exp $
+# $Id: std_err.sh,v 2.5 2004/06/21 14:01:00 profw Exp $
 # Copyright 1994, The Regents of the University of Colorado
 
 # This file is part of the Eli translator construction system.
@@ -18,11 +18,11 @@
 # with Eli; see the file COPYING.  If not, write to the Free Software
 # Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
-PKG=$1;shift; ODIN_HOOK=$1;shift; ODIN_atomic=$1;shift; ODIN_docref=$1;shift;
-
-# EXEC (std_err.sh) (.) (+hookvalue) (:FILE) (+docref)
+# EXEC (std_err.sh) (+hookvalue) (:FILE) (+docref)
 #   => (:std_err);
 
+ODIN_HOOK=$1;shift; ODIN_atomic=$1;shift; ODIN_docref=$1;shift;
+
 if test -z "$ODIN_docref"
 then cp "$ODIN_HOOK" std_err
 else $ODINCACHE/PKGS/skeleton/sed.exe -f $ODIN_atomic $ODIN_HOOK >std_err
