@@ -1,6 +1,6 @@
 #!/bin/sh
-# $Id: tex_input.sh,v 2.4 2002/05/08 15:00:56 waite Exp $
-# Copyright 1993, The Regents of the University of Colorado
+# $Id: tex_input.sh,v 2.8 2004/08/20 13:19:59 profw Exp $
+# Copyright 2004, The Regents of the University of Colorado
 
 # This file is part of the Eli translator construction system.
 
@@ -18,27 +18,29 @@
 # with Eli; see the file COPYING.  If not, write to the Free Software
 # Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
-ODIN_RUNDIR=`pwd`;
-PKG=$1;shift; ODIN_tnf=$1;shift; ODIN_single=$1;shift;
+# EXEC (tex_input.sh) (:tnf) (+single)
+#   => (:tex_input);
 
-#tex_input 'TeX input modified for single/double sided'* :
-#	USER
-#		: tnf
-#		+ single
+ODIN_tnf=$1;shift; ODIN_single=$1;shift;
 
-if test ! -r "$ODIN_tnf"
-then
-	echo "Couldn't open file $ODIN_tnf for input" > ERRORS
-	exit 0
-fi
+touch script
 
 if test '' != "$ODIN_single"
 then
-	$ODINCACHE/PKGS/skeleton/sed.exe -e \
-		's/^\@setchapternewpage odd/\@setchapternewpage on/' \
-		"$ODIN_tnf" > tex_input
-else
-	cp "$ODIN_tnf" tex_input
+  echo '/^@setchapternewpage/s/odd/on/
+        /^@headings/s/double/single/
+        /^@titlepage/,/^@end titlepage/s/^\@page/@comment/' >> script
+elif test "`$ODINCACHE/PKGS/skeleton/sed.exe -n -e '/^@titlepage/,/^@end titlepage/s/^@page/page/p' $ODIN_tnf`" = ''
+then
+  echo '/^@end titlepage/i\
+@page' >> script
 fi
 
-exit 0
+if grep '^@contents' $ODIN_tnf > /dev/null
+then
+  echo '/^@contents/d
+        /^@end titlepage/a\
+@contents' >> script
+fi
+
+$ODINCACHE/PKGS/skeleton/sed.exe -f script $ODIN_tnf > tex_input
