@@ -1,4 +1,4 @@
-static char rcsid[] = "$Id: texindex.c,v 1.15 2001/06/07 17:38:38 waite Exp $";
+static char rcsid[] = "$Id: texindex.c,v 1.16 2003/06/30 02:35:07 waite Exp $";
 
 /* Prepare Tex index dribble output into an actual index.
    Copyright (C) 1987 Free Software Foundation, Inc.
@@ -203,7 +203,7 @@ char *tempdir;
 
 /* Start of filename to use for temporary files.  */
 
-char *tempbase;
+char tempbase[15];
 
 /* Number of last temporary file.  */
 
@@ -288,7 +288,13 @@ main (argc, argv)
 
   decode_command (argc, argv);
 
-  tempbase = mkstemp (concat ("txiXXXXXX", "", ""));
+  /* Need to generate a portion of a temp file name.  The original */
+  /* method doesn't work because mktemp might simply start numbers */
+  /* from 1 and look for file name conflicts.  But tempbase is only */
+  /* PART of the ultimate name, so the conflict check does no good. */
+  /* tempbase = mktemp (concat ("txiXXXXXX", "", "")); */
+  /* Instead, we build our process ID into tempbase.  */
+  sprintf (tempbase, "txi%d", getpid());
 
   /* Process input files completely, one by one.  */
 
