@@ -1,4 +1,4 @@
-/* $Id: p2clib.c,v 1.5 1994/02/25 23:32:33 kadhim Exp $ */
+/* $Id: p2clib.c,v 1.6 2004/08/01 01:44:25 profw Exp $ */
 /*  LAST EDIT: Mon Apr 16 13:20:07 MDT 1990 by Steve Levi (levi)  */
 
 /* Run-time library for use with "p2c", the Pascal to C translator */
@@ -376,7 +376,7 @@ FILE *f;
     if (ch == EOF)
 	return EOF;
     ungetc(ch, f);
-    return (ch == '\n') ? ' ' : ch;
+    return (ch == '\n' || ch == '\r') ? ' ' : ch;
 }
 
 
@@ -412,6 +412,10 @@ FILE *f;
     if (ch == EOF)
         return 1;
     ungetc(ch, f);
+    if (ch == '\r') {
+      if ((ch = getc(f)) != '\n') ungetc(ch, f);
+      return 1;
+    }
     return (ch == '\n');
 }
 
@@ -429,6 +433,11 @@ int len;
 	if (len <= 0)
 	    return;
 	ch = getc(f);
+        if (ch == '\r') {
+          if ((ch = getc(f)) != '\n') ungetc(ch, f);
+          ch = '\n';
+          break;
+        }
 	if (ch == EOF || ch == '\n')
 	    break;
 	*s++ = ch;
@@ -449,6 +458,11 @@ int len;
 
     for (;;) {
 	ch = getc(f);
+        if (ch == '\r') {
+          if ((ch = getc(f)) != '\n') ungetc(ch, f);
+          ch = '\n';
+          break;
+        }
 	if (ch == EOF || ch == '\n')
 	    break;
 	if (len > 0) {
