@@ -17,7 +17,7 @@ You should have received a copy of the GNU General Public License along
 with PGS; see the file COPYING.  If not, write to the Free Software
 Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
-static char rcsid[] = {"$Id: pgs_optim.c,v 1.16 2000/06/01 17:07:51 waite Exp $"};
+static char rcsid[] = {"$Id: pgs_optim.c,v 1.17 2004/08/01 01:44:25 profw Exp $"};
 
 /* Output from p2c, the Pascal-to-C translator */
 /* From input file "optimierung.p" */
@@ -2843,8 +2843,12 @@ Char *argv[];
       char C; int Snr, Laenge;
 
       (void)fscanf(Symbolda, "%5d%4d ", &Snr, &Laenge);
-      C = getc(Symbolda);
-      while (C != '\n') { obstack_1grow(&SymObs, C); C = getc(Symbolda); }
+      for (C = getc(Symbolda); C != '\n' && C != '\r'; C = getc(Symbolda)) {
+        obstack_1grow(&SymObs, C);
+      }
+      if (C == '\r') {
+        if ((C = getc(Symbolda)) != '\n') ungetc(C, stdin);
+      }
       obstack_1grow(&SymObs, '\0');
 
       SymbolTable[Snr] = (Drusym *)malloc(sizeof(Drusym));
