@@ -1,5 +1,5 @@
 #!/bin/sh
-# $Id: msgtext.sh,v 2.6 2002/05/08 15:01:05 waite Exp $
+# $Id: msgtext.sh,v 2.7 2003/06/30 02:30:08 waite Exp $
 # Copyright 1997, The Regents of the University of Colorado
 
 # This file is part of the Eli translator construction system.
@@ -18,15 +18,15 @@
 # with Eli; see the file COPYING.  If not, write to the Free Software
 # Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
-# EXEC (msgtext.sh) (.) (:filtered) (:errfiles :list :pasted)
+# EXEC (msgtext.sh) (sed.exe) (:filtered) (:errfiles :list :pasted)
 #   => (:msgtext);
 
-PKG=$1;shift; ODIN_sorted_errors=$1;shift; ODIN_files=$1;shift;
+SED=$1;shift; ODIN_sorted_errors=$1;shift; ODIN_files=$1;shift;
 touch msgtext
 
 if test ! -s "$ODIN_sorted_errors"; then exit 0; fi
 
-$PKG/sed.exe -e "s;$ODINCACHE;"'$ODINCACHE;g
+$SED -e "s;$ODINCACHE;"'$ODINCACHE;g
 /^\. 0 0 \(.*\)$/s//\1/
 /^\([^ 	]\+\) \([0-9]\+\) \([0-9]\+\) \(.*\)$/s//"\1", line \2,\3: \4/
 ' $ODIN_sorted_errors > msgtext
