@@ -1,5 +1,5 @@
 #! /bin/sh
-# $Id: viewlist.sh,v 2.5 2002/05/08 15:01:06 waite Exp $
+# $Id: viewlist.sh,v 2.6 2003/06/30 02:30:09 waite Exp $
 # Copyright 1996, The Regents of the University of Colorado
 
 # This file is part of the Eli translator construction system.
@@ -18,12 +18,11 @@
 # with Eli; see the file COPYING.  If not, write to the Free Software
 # Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
-ODIN_RUNDIR=`pwd`;
-PKG=$1;shift; ODIN_compound=$1;shift;
+# EXEC (viewlist.sh) (sed.exe) (:LIST :dir_of :vir_dir) (doview)
+#   NEEDS (:LIST)
+#   => (:viewlist);
 
-#viewlist "Display mechanism for compound files"* :
-#	BROWSER
-#		: .compound
+SED=$1;shift; ODIN_compound=$1;shift; ODIN_doview=$1;shift;
 
-$PKG/sed.exe -e "s;ODIN_compound;$ODIN_compound;g" $PKG/doview > viewlist
+$SED -e "s;ODIN_compound;$ODIN_compound;g" $ODIN_doview > viewlist
 chmod +x viewlist
