@@ -1,9 +1,11 @@
 #! /bin/sh
 
 # EXEC (fmtcmd.sh) (:rootFileName +texsppt=(:texsp) :texfiles :ls) (+tex) (+latex)
+#      (+usepdf)
 #    => (:fmtcmd);
 
 ODIN_rootFile=$1;shift; ODIN_tex=$1;shift; ODIN_latex=$1;shift;
+ODIN_pdf=$1;shift;
 
 rootFile=`cat $ODIN_rootFile`
 if [ "$rootFile" = '' ]
@@ -19,3 +21,11 @@ elif fgrep -e '\documentstyle' -e '\documentclass' $rootFile > /dev/null
 then echo latex > fmtcmd
 else echo tex > fmtcmd
 fi
+
+if [ "$ODIN_pdf" != '' ]
+then
+  sed -e 's/.*/pdf&/' fmtcmd > pdfcmd
+  mv pdfcmd fmtcmd
+else :
+fi
+
