@@ -3,13 +3,13 @@
 # EXEC (tex.sh) (:fmtcmd) (:rootName) (:texsp) (:tex.vtd :texauxin.vtd :vir_dir)&
 #    NEEDS (:texbasis :extract=:tex) (:texbasis :extract=:sty)
 #      (:tex.vtd :texauxin.vtd :vir_tgt.list)&
-#    => (:dvi) (:tex.log) (:citations) (:texauxout);
+#    => (:dvi) (:tex.log) (:citations) (:texauxout) (:texpdf);
 
 ODIN_fmtcmd=$1;shift; ODIN_root=$1;shift; ODIN_search=$1;shift; ODIN_aux=$1;shift;
 mkdir texauxout
 
 for d in `cat $ODIN_search`; do sp=$sp"$d":; done
-TEXINPUTS=$sp"$TEXINPUTS"; export TEXINPUTS;
+TEXINPUTS=.:$sp"$TEXINPUTS"; export TEXINPUTS;
 
 if [ -d "$ODIN_aux" ]
 then
@@ -24,6 +24,7 @@ cd texauxout
 cd ..
 
 if [ -f texauxout/*.dvi ] ; then mv texauxout/*.dvi dvi; fi
+if [ -f texauxout/*.pdf ] ; then mv texauxout/*.pdf texpdf; fi
 if [ -f texauxout/*.log ]
 then mv texauxout/*.log tex.log
 else touch tex.log
@@ -43,9 +44,10 @@ fi
 if [ -d "$ODIN_aux" ] && ( diff $ODIN_aux texauxout > /dev/null )
 then
   if [ -s citations -a ! \( -f texauxout/`cat $ODIN_root`.bbl \) ]
-  then rm -f dvi
+  then rm -f dvi texpdf
   fi
-else rm -f dvi
+else rm -f dvi texpdf
 fi
 
 rm -f texauxout/*.bbl
+
